pub enum CompressionAlgorithm {
Passthrough,
Snappy,
Lzma,
}Expand description
CompressionAlgorithm is an enumeration that defines the different compression algorithms supported for compressing the content of objects.
Variants
Passthrough
Represents the “No compression” algorithm.
Snappy
Represents the Snappy algorithm.
Lzma
Represents the LZMA algorithm.
Implementations
Sourceimpl CompressionAlgorithm
impl CompressionAlgorithm
Sourcepub fn compress(&self, data: &[u8]) -> Result<Vec<u8>, CompressionError>
pub fn compress(&self, data: &[u8]) -> Result<Vec<u8>, CompressionError>
compress returns the compressed data using the given algorithm.
Sourcepub fn decompress(&self, data: &[u8]) -> Result<Vec<u8>, CompressionError>
pub fn decompress(&self, data: &[u8]) -> Result<Vec<u8>, CompressionError>
decompress returns the decompressed data using the given algorithm. The data must be compressed using the same algorithm.