CompressionAlgorithm

Enum CompressionAlgorithm 

pub enum CompressionAlgorithm {
    Passthrough,
    Snappy,
    Lzma,
}
CompressionAlgorithm is an enumeration that defines the different compression algorithms supported for compressing the content of objects. The compression algorithm specified here are relevant algorithms for compressing data on-chain, which means that they are fast to compress and decompress, and have a low computational cost.

The order of the compression algorithms is based on their estimated computational cost (quite opinionated) during both compression and decompression, ranging from the lowest to the highest. This particular order is utilized to establish the default compression algorithm for storing an object.

Variants



Passthrough

Passthrough

Represents no compression algorithm. The object is stored as is without any compression.



Snappy

Snappy

Represents the Snappy algorithm. Snappy is a compression/decompression algorithm that does not aim for maximum compression. Instead, it aims for very high speeds and reasonable compression.

See the snappy web page for more information.



Lzma

Lzma

Represents the LZMA algorithm. LZMA is a lossless data compression/decompression algorithm that features a high compression ratio and a variable compression-dictionary size up to 4 GB.

See the LZMA wiki page for more information.

Implementations