BucketConfigBuilder

Struct BucketConfigBuilder 

pub struct BucketConfigBuilder { /* private fields */ }
Builder for BucketConfig.

Implementations

Source

impl BucketConfigBuilder

pub fn hash_algorithm<VALUE: Into<HashAlgorithm>>( &mut self, value: VALUE, ) -> &mut Self

The algorithm used to hash the content of the objects to generate the id of the objects. The algorithm is optional and if not set, the default algorithm is used.

The default algorithm is Sha256 if not set.

pub fn accepted_compression_algorithms<VALUE: Into<Vec<CompressionAlgorithm>>>( &mut self, value: VALUE, ) -> &mut Self

The acceptable compression algorithms for the objects in the bucket. If this parameter is not set, then all compression algorithms are accepted. If this parameter is set, then only the compression algorithms in the array are accepted.

When an object is stored in the bucket without a specified compression algorithm, the first algorithm in the array is used. Therefore, the order of the algorithms in the array is significant. Typically, the most efficient compression algorithm, such as the NoCompression algorithm, should be placed first in the array.

Any attempt to store an object using a different compression algorithm than the ones specified here will fail.

pub fn build(&self) -> Result<BucketConfig, BucketConfigBuilderError>

Builds a new BucketConfig.

Errors

If a required field has not been initialized.