pub struct BucketLimits {
pub max_total_size: Option<Uint128>,
pub max_objects: Option<Uint128>,
pub max_object_size: Option<Uint128>,
pub max_object_pins: Option<Uint128>,
}Expand description
BucketLimits is the type of the limits of a bucket.
The limits are optional and if not set, there is no limit.
Fields
max_total_size: Option<Uint128>The maximum total size of the objects in the bucket.
max_objects: Option<Uint128>The maximum number of objects in the bucket.
max_object_size: Option<Uint128>The maximum size of the objects in the bucket.
max_object_pins: Option<Uint128>The maximum number of pins in the bucket for an object.