pub struct BucketLimitsBuilder { /* private fields */ }Expand description
Builder for BucketLimits.
Implementations
Sourceimpl BucketLimitsBuilder
impl BucketLimitsBuilder
Sourcepub fn max_total_size<VALUE: Into<Uint128>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_total_size<VALUE: Into<Uint128>>( &mut self, value: VALUE, ) -> &mut Self
The maximum total size of the objects in the bucket.
Sourcepub fn max_objects<VALUE: Into<Uint128>>(&mut self, value: VALUE) -> &mut Self
pub fn max_objects<VALUE: Into<Uint128>>(&mut self, value: VALUE) -> &mut Self
The maximum number of objects in the bucket.
Sourcepub fn max_object_size<VALUE: Into<Uint128>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_object_size<VALUE: Into<Uint128>>( &mut self, value: VALUE, ) -> &mut Self
The maximum size of the objects in the bucket.
Sourcepub fn max_object_pins<VALUE: Into<Uint128>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_object_pins<VALUE: Into<Uint128>>( &mut self, value: VALUE, ) -> &mut Self
The maximum number of pins in the bucket for an object.
Sourcepub fn build(&self) -> Result<BucketLimits, BucketLimitsBuilderError>
pub fn build(&self) -> Result<BucketLimits, BucketLimitsBuilderError>