pub struct BucketStat {
pub size: Uint128,
pub compressed_size: Uint128,
pub object_count: Uint128,
}Expand description
BucketStat
BucketStat is the type of the statistics of a bucket.
Fields
size: Uint128The total size of the objects contained in the bucket.
compressed_size: Uint128The total size of the objects contained in the bucket after compression.
object_count: Uint128The number of objects in the bucket.