pub struct BucketStatBuilder { /* private fields */ }Expand description
Builder for BucketStat.
Implementations
Sourceimpl BucketStatBuilder
impl BucketStatBuilder
Sourcepub fn size(&mut self, value: Uint128) -> &mut Self
pub fn size(&mut self, value: Uint128) -> &mut Self
The total size of the objects contained in the bucket.
Sourcepub fn compressed_size(&mut self, value: Uint128) -> &mut Self
pub fn compressed_size(&mut self, value: Uint128) -> &mut Self
The total size of the objects contained in the bucket after compression.
Sourcepub fn object_count(&mut self, value: Uint128) -> &mut Self
pub fn object_count(&mut self, value: Uint128) -> &mut Self
The number of objects in the bucket.
Sourcepub fn build(&self) -> Result<BucketStat, BucketStatBuilderError>
pub fn build(&self) -> Result<BucketStat, BucketStatBuilderError>