pub struct ObjectResponse {
pub id: ObjectId,
pub owner: String,
pub is_pinned: bool,
pub size: Uint128,
pub compressed_size: Uint128,
pub compression_algorithm: CompressionAlgorithm,
}Expand description
ObjectResponse
ObjectResponse is the response of the Object query.
Fields
id: ObjectIdThe id of the object.
owner: StringThe owner of the object.
is_pinned: boolTells if the object is pinned by at least one address.
size: Uint128The size of the object.
compressed_size: Uint128The size of the object when compressed. If the object is not compressed, the value is the
same as size.
compression_algorithm: CompressionAlgorithmThe compression algorithm used to compress the content of the object.