pub struct PaginationConfig {
pub max_page_size: u32,
pub default_page_size: u32,
}Expand description
PaginationConfig is the type carrying configuration for paginated queries.
The fields are optional and if not set, there is a default configuration.
Fields
max_page_size: u32The maximum elements a page can contain.
Shall be less than u32::MAX - 1.
Default to ‘30’ if not set.
default_page_size: u32The default number of elements in a page.
Shall be less or equal than max_page_size.
Default to ‘10’ if not set.