pub enum HashAlgorithm {
MD5,
Sha224,
Sha256,
Sha384,
Sha512,
}Expand description
HashAlgorithm is an enumeration that defines the different hash algorithms supported for hashing the content of objects.
Variants
MD5
Represents the MD5 algorithm.
Sha224
Represents the SHA-224 algorithm.
Sha256
Represents the SHA-256 algorithm.
Sha384
Represents the SHA-384 algorithm.
Sha512
Represents the SHA-512 algorithm.