pub struct BucketConfig {
pub hash_algorithm: HashAlgorithm,
pub accepted_compression_algorithms: Vec<CompressionAlgorithm>,
}Expand description
BucketConfig is the type of the configuration of a bucket.
The configuration is set at the instantiation of the bucket, and is immutable and cannot be changed.
Fields
hash_algorithm: HashAlgorithmThe algorithm used to hash the content of the objects to generate the id of the objects. The algorithm is optional and if not set, the default algorithm is used.
The default algorithm is Sha256.
accepted_compression_algorithms: Vec<CompressionAlgorithm>The accepted compression algorithms for the objects in the bucket.
The default is all compression algorithms.